DecodeError

Enum DecodeError 

pub enum DecodeError {
    IO(Error),
    GreaterLen,
    SmallerLen,
    PrimIndef,
    TagTypeMismatch,
    ExplicitTag,
    IndefiniteLen,
    IndefiniteLenEnd,
    Custom(&'static str),
}
Errors that can occur while decoding an ASN.1 element.

Variants



IO(Error)

Generic IO Error.



GreaterLen

Child element(s) decoded to greater length than the parent’s tag.



SmallerLen

Child element(s) decoded to smaller length than the parent’s tag.



PrimIndef

Primitive value encoded with an indefinite length.



TagTypeMismatch

Decoded tag does not match the expected tag for this type.



ExplicitTag

An explicit tag appeared where an Implicit tag was expected.



IndefiniteLen

Indefinite length encoding appeared when definite length encoding was expected.



IndefiniteLenEnd

Indefinite length encoding was started, but no terminator was found at the end.



Custom(&'static str)

Custom decoding error.